PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Py.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Namespaces | Macros | Functions
Py.hpp File Reference
`#include <numpy/ndarrayobject.h>`
`#include "Geometry.hpp"`
`#include "PyObject.hpp"`

Go to the source code of this file.

## Data Structures
class | py::GIL_guard
| The GIL. More...

## Namespaces
namespace | py

## Macros
#define | PY_ONLY(args...)
#define | NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
#define | NO_IMPORT_ARRAY
#define | PY_ARRAY_UNIQUE_SYMBOL _pcbenv2_module_PyArray_API

## Functions
template<typename Ty = PyObject>
Ty * | py::ValueError (const char *s)
| Error return helpers.
template<typename Ty = PyObject>
Ty * | py::MemoryError (const char *s)
template<typename Ty = PyObject>
Ty * | py::Exception (PyObject *exc, const char *s)
PyObject * | py::Exception (const std::exception &e)
PyObject * | py::String (const char *s)
| Conversion to Python.
PyObject * | py::String (const std::string &s)
bool | py::TupleN_Check (PyObject *py, uint n)
| Conversion from Python.
bool | py::TupleMin_Check (PyObject *py, uint n)
double | py::Number_AsDouble (PyObject *py)
bool | py::String_Check (PyObject *py)
std::string | py::String_AsStdString (PyObject *py)
std::string_view | py::String_AsStringView (PyObject *py)
std::string | py::String_AsStdString (PyObject *py, const char *error)
void | py::Dict_StealItemString (PyObject *dict, const char *key, PyObject *v)
void | py::Dict_StealItem (PyObject *dict, PyObject *key, PyObject *v)
void | py::DECREF_safe (PyObject *v)
PyObject * | py::None ()
PyObject * | py::NewRef (PyObject *py)

## Macro Definition Documentation

## ◆ NO_IMPORT_ARRAY

#define NO_IMPORT_ARRAY

## ◆ NPY_NO_DEPRECATED_API

#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION

## ◆ PY_ARRAY_UNIQUE_SYMBOL

#define PY_ARRAY_UNIQUE_SYMBOL _pcbenv2_module_PyArray_API

## ◆ PY_ONLY

#define PY_ONLY | ( |  | args... | ) |

Value:
args